﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/quicksight/QuickSight_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/quicksight/model/GeospatialLayerType.h>
#include <aws/quicksight/model/GeospatialDataSourceItem.h>
#include <aws/quicksight/model/Visibility.h>
#include <aws/quicksight/model/GeospatialLayerDefinition.h>
#include <aws/quicksight/model/TooltipOptions.h>
#include <aws/quicksight/model/GeospatialLayerJoinDefinition.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/quicksight/model/LayerCustomAction.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace QuickSight
{
namespace Model
{

  /**
   * <p>The properties for a single geospatial layer.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/quicksight-2018-04-01/GeospatialLayerItem">AWS
   * API Reference</a></p>
   */
  class GeospatialLayerItem
  {
  public:
    AWS_QUICKSIGHT_API GeospatialLayerItem();
    AWS_QUICKSIGHT_API GeospatialLayerItem(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API GeospatialLayerItem& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>The ID of the layer.</p>
     */
    inline const Aws::String& GetLayerId() const{ return m_layerId; }
    inline bool LayerIdHasBeenSet() const { return m_layerIdHasBeenSet; }
    inline void SetLayerId(const Aws::String& value) { m_layerIdHasBeenSet = true; m_layerId = value; }
    inline void SetLayerId(Aws::String&& value) { m_layerIdHasBeenSet = true; m_layerId = std::move(value); }
    inline void SetLayerId(const char* value) { m_layerIdHasBeenSet = true; m_layerId.assign(value); }
    inline GeospatialLayerItem& WithLayerId(const Aws::String& value) { SetLayerId(value); return *this;}
    inline GeospatialLayerItem& WithLayerId(Aws::String&& value) { SetLayerId(std::move(value)); return *this;}
    inline GeospatialLayerItem& WithLayerId(const char* value) { SetLayerId(value); return *this;}
    ///@}

    ///@{
    /**
     * <p>The layer type.</p>
     */
    inline const GeospatialLayerType& GetLayerType() const{ return m_layerType; }
    inline bool LayerTypeHasBeenSet() const { return m_layerTypeHasBeenSet; }
    inline void SetLayerType(const GeospatialLayerType& value) { m_layerTypeHasBeenSet = true; m_layerType = value; }
    inline void SetLayerType(GeospatialLayerType&& value) { m_layerTypeHasBeenSet = true; m_layerType = std::move(value); }
    inline GeospatialLayerItem& WithLayerType(const GeospatialLayerType& value) { SetLayerType(value); return *this;}
    inline GeospatialLayerItem& WithLayerType(GeospatialLayerType&& value) { SetLayerType(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>The data source for the layer.</p>
     */
    inline const GeospatialDataSourceItem& GetDataSource() const{ return m_dataSource; }
    inline bool DataSourceHasBeenSet() const { return m_dataSourceHasBeenSet; }
    inline void SetDataSource(const GeospatialDataSourceItem& value) { m_dataSourceHasBeenSet = true; m_dataSource = value; }
    inline void SetDataSource(GeospatialDataSourceItem&& value) { m_dataSourceHasBeenSet = true; m_dataSource = std::move(value); }
    inline GeospatialLayerItem& WithDataSource(const GeospatialDataSourceItem& value) { SetDataSource(value); return *this;}
    inline GeospatialLayerItem& WithDataSource(GeospatialDataSourceItem&& value) { SetDataSource(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>The label that is displayed for the layer.</p>
     */
    inline const Aws::String& GetLabel() const{ return m_label; }
    inline bool LabelHasBeenSet() const { return m_labelHasBeenSet; }
    inline void SetLabel(const Aws::String& value) { m_labelHasBeenSet = true; m_label = value; }
    inline void SetLabel(Aws::String&& value) { m_labelHasBeenSet = true; m_label = std::move(value); }
    inline void SetLabel(const char* value) { m_labelHasBeenSet = true; m_label.assign(value); }
    inline GeospatialLayerItem& WithLabel(const Aws::String& value) { SetLabel(value); return *this;}
    inline GeospatialLayerItem& WithLabel(Aws::String&& value) { SetLabel(std::move(value)); return *this;}
    inline GeospatialLayerItem& WithLabel(const char* value) { SetLabel(value); return *this;}
    ///@}

    ///@{
    /**
     * <p>The state of visibility for the layer.</p>
     */
    inline const Visibility& GetVisibility() const{ return m_visibility; }
    inline bool VisibilityHasBeenSet() const { return m_visibilityHasBeenSet; }
    inline void SetVisibility(const Visibility& value) { m_visibilityHasBeenSet = true; m_visibility = value; }
    inline void SetVisibility(Visibility&& value) { m_visibilityHasBeenSet = true; m_visibility = std::move(value); }
    inline GeospatialLayerItem& WithVisibility(const Visibility& value) { SetVisibility(value); return *this;}
    inline GeospatialLayerItem& WithVisibility(Visibility&& value) { SetVisibility(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>The definition properties for a layer.</p>
     */
    inline const GeospatialLayerDefinition& GetLayerDefinition() const{ return m_layerDefinition; }
    inline bool LayerDefinitionHasBeenSet() const { return m_layerDefinitionHasBeenSet; }
    inline void SetLayerDefinition(const GeospatialLayerDefinition& value) { m_layerDefinitionHasBeenSet = true; m_layerDefinition = value; }
    inline void SetLayerDefinition(GeospatialLayerDefinition&& value) { m_layerDefinitionHasBeenSet = true; m_layerDefinition = std::move(value); }
    inline GeospatialLayerItem& WithLayerDefinition(const GeospatialLayerDefinition& value) { SetLayerDefinition(value); return *this;}
    inline GeospatialLayerItem& WithLayerDefinition(GeospatialLayerDefinition&& value) { SetLayerDefinition(std::move(value)); return *this;}
    ///@}

    ///@{
    
    inline const TooltipOptions& GetTooltip() const{ return m_tooltip; }
    inline bool TooltipHasBeenSet() const { return m_tooltipHasBeenSet; }
    inline void SetTooltip(const TooltipOptions& value) { m_tooltipHasBeenSet = true; m_tooltip = value; }
    inline void SetTooltip(TooltipOptions&& value) { m_tooltipHasBeenSet = true; m_tooltip = std::move(value); }
    inline GeospatialLayerItem& WithTooltip(const TooltipOptions& value) { SetTooltip(value); return *this;}
    inline GeospatialLayerItem& WithTooltip(TooltipOptions&& value) { SetTooltip(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>The join definition properties for a layer.</p>
     */
    inline const GeospatialLayerJoinDefinition& GetJoinDefinition() const{ return m_joinDefinition; }
    inline bool JoinDefinitionHasBeenSet() const { return m_joinDefinitionHasBeenSet; }
    inline void SetJoinDefinition(const GeospatialLayerJoinDefinition& value) { m_joinDefinitionHasBeenSet = true; m_joinDefinition = value; }
    inline void SetJoinDefinition(GeospatialLayerJoinDefinition&& value) { m_joinDefinitionHasBeenSet = true; m_joinDefinition = std::move(value); }
    inline GeospatialLayerItem& WithJoinDefinition(const GeospatialLayerJoinDefinition& value) { SetJoinDefinition(value); return *this;}
    inline GeospatialLayerItem& WithJoinDefinition(GeospatialLayerJoinDefinition&& value) { SetJoinDefinition(std::move(value)); return *this;}
    ///@}

    ///@{
    /**
     * <p>A list of custom actions for a layer.</p>
     */
    inline const Aws::Vector<LayerCustomAction>& GetActions() const{ return m_actions; }
    inline bool ActionsHasBeenSet() const { return m_actionsHasBeenSet; }
    inline void SetActions(const Aws::Vector<LayerCustomAction>& value) { m_actionsHasBeenSet = true; m_actions = value; }
    inline void SetActions(Aws::Vector<LayerCustomAction>&& value) { m_actionsHasBeenSet = true; m_actions = std::move(value); }
    inline GeospatialLayerItem& WithActions(const Aws::Vector<LayerCustomAction>& value) { SetActions(value); return *this;}
    inline GeospatialLayerItem& WithActions(Aws::Vector<LayerCustomAction>&& value) { SetActions(std::move(value)); return *this;}
    inline GeospatialLayerItem& AddActions(const LayerCustomAction& value) { m_actionsHasBeenSet = true; m_actions.push_back(value); return *this; }
    inline GeospatialLayerItem& AddActions(LayerCustomAction&& value) { m_actionsHasBeenSet = true; m_actions.push_back(std::move(value)); return *this; }
    ///@}
  private:

    Aws::String m_layerId;
    bool m_layerIdHasBeenSet = false;

    GeospatialLayerType m_layerType;
    bool m_layerTypeHasBeenSet = false;

    GeospatialDataSourceItem m_dataSource;
    bool m_dataSourceHasBeenSet = false;

    Aws::String m_label;
    bool m_labelHasBeenSet = false;

    Visibility m_visibility;
    bool m_visibilityHasBeenSet = false;

    GeospatialLayerDefinition m_layerDefinition;
    bool m_layerDefinitionHasBeenSet = false;

    TooltipOptions m_tooltip;
    bool m_tooltipHasBeenSet = false;

    GeospatialLayerJoinDefinition m_joinDefinition;
    bool m_joinDefinitionHasBeenSet = false;

    Aws::Vector<LayerCustomAction> m_actions;
    bool m_actionsHasBeenSet = false;
  };

} // namespace Model
} // namespace QuickSight
} // namespace Aws
